@@ -13,6 +13,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import os
 from unittest import mock
 
 from oslo_utils import netutils
@@ -22,13 +23,13 @@ from zaqarclient.tests import base
 from zaqarclient.tests.transport import dummy
 
 
-MY_IP = netutils.get_my_ipv4()
+MY_IP = os.environ.get('ZAQAR_SERVICE_HOST', netutils.get_my_ipv4())
 
 
 class QueuesTestBase(base.TestBase):
 
     transport_cls = dummy.DummyTransport
-    url = 'http://%s:8888' % MY_IP
+    url = 'http://%s:8888' % netutils.escape_ipv6(MY_IP)
     version = 1
 
     def setUp(self):
